@@ -15,10 +15,14 @@ my $control = MIDI::RtController->new(
     verbose => 1,
 );
 
+my $filter0 = MIDI::RtController::Filter::CC->new(rtc => $control);
 my $filter1 = MIDI::RtController::Filter::CC->new(rtc => $control);
 my $filter2 = MIDI::RtController::Filter::CC->new(rtc => $control);
 my $filter3 = MIDI::RtController::Filter::CC->new(rtc => $control);
 
+$filter0->control(77); # oscillator 1 waveform
+$filter0->value(0);    # 0 = sawtooth
+
 $filter1->control(1); # mod-wheel
 # $filter1->range_bottom(10);
 # $filter1->range_top(100);
@@ -43,6 +47,7 @@ $filter3->time_step(0.5);
 # $filter3->step_up(10);
 # $filter3->step_down(2);
 
+$control->add_filter('single', ['all'], $filter0->curry::single);
 $control->add_filter('scatter', ['all'], $filter1->curry::scatter);
 $control->add_filter('stair_step', ['all'], $filter2->curry::stair_step);
 $control->add_filter('breathe', ['all'], $filter3->curry::breathe);
